@@ -33,9 +33,10 @@
 #  define LIBKGEOMAP_DEPRECATED_NO_EXPORT LIBKGEOMAP_NO_EXPORT LIBKGEOMAP_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define LIBKGEOMAP_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef LIBKGEOMAP_NO_DEPRECATED
+#    define LIBKGEOMAP_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
